## Working with neptoon in python

If you want to simply process your site, it's recommended to use the config system. However, there may be times when you want to work with neptoon directly with your favourite python IDE.

A good starting point for working with neptoon in python is to checkout the [examples](neptoon-examples.md). Here you can download python notebooks and get started quickly with some sample data. Use these as a framework for setting up pipelines for your own sites. 

The rest of this section will outline in detail how each of the steps in the [workflow](workflow-description.md) operate. The steps are expected to be somewhat linear based on the theory of CRNS. For example, we need to do some QA before corrections, and we need to do corrections before we calibrate the sensor. 